@@ -1,13 +1,3 @@
-#  #' Prints an emdiObject
-#  #'
-#  #' Basic information of an emdi object is printed.
-#  #' @param x an x of type "emdi", representing point and MSE
-#  #' estimates obtained by direct estimation (see also \code{\link{direct}}),
-#  #' the Fay-Herriot model and a range of extensions (see also \code{\link{fh}}),
-#  #' or Empirical Best Prediction (see also \code{\link{ebp}}).
-#  #' @param ... optional arguments passed to \code{\link{print.default}}.
-#  #' @seealso \code{\link{direct}}, \code{\link{ebp}}, \code{\link{fh}},
-#  #'  \code{\link{emdiObject}}
 #' @export
 print.direct <- function(x, ...) {
   throw_class_error(x, "direct")
@@ -23,42 +13,48 @@ print.direct <- function(x, ...) {
 #' @export
 print.ebp <- function(x, ...) {
   throw_class_error(x, "ebp")
-  
-  if(is.null(x$call$weights)) {
+
+  if (is.null(x$call$weights)) {
     cat("Empirical Best Prediction\n")
   } else {
     cat("Empirical Best Prediction with sampling weights\n")
   }
-  
+
   cat("\n")
   cat("Out-of-sample domains: ", x$framework$N_dom_unobs, "\n")
   cat("In-sample domains: ", x$framework$N_dom_smp, "\n")
-  
+
   if (x$transformation == "box.cox") {
-    transform_method <- data.frame(Transformation  = x$transformation,
-                                   Method          = x$method,
-                                   Optimal_lambda  = x$transform_param$optimal_lambda,
-                                   Shift_parameter = round(x$transform_param$shift_par,3),
-                                   row.names       = ""
+    transform_method <- data.frame(
+      Transformation = x$transformation,
+      Method = x$method,
+      Optimal_lambda =
+        x$transform_param$optimal_lambda,
+      Shift_parameter =
+        round(x$transform_param$shift_par, 3),
+      row.names = ""
     )
   } else if (x$transformation == "dual") {
-    transform_method <- data.frame(Transformation  = x$transformation,
-                                   Method          = x$method,
-                                   Optimal_lambda  = x$transform_param$optimal_lambda,
-                                   row.names       = ""
+    transform_method <- data.frame(
+      Transformation = x$transformation,
+      Method = x$method,
+      Optimal_lambda =
+        x$transform_param$optimal_lambda,
+      row.names = ""
     )
   } else if (x$transformation == "log") {
-    transform_method <- data.frame(Transformation  = x$transformation,
-                                   Shift_parameter = round(x$transform_param$shift_par,3),
-                                   row.names       = ""
+    transform_method <- data.frame(
+      Transformation = x$transformation,
+      Shift_parameter =
+        round(x$transform_param$shift_par, 3),
+      row.names = ""
     )
-  }
-  else if (x$transformation == "no") {
+  } else if (x$transformation == "no") {
     transform_method <- NULL
   }
-  
+
   cat("\n")
-  if(is.null(transform_method)){
+  if (is.null(transform_method)) {
     cat("Transformation: No transformation \n")
   } else {
     cat("Transformation:\n")
@@ -81,7 +77,8 @@ print.fh <- function(x, ...) {
   cat("Empirical Best Linear Unbiased Prediction (Fay-Herriot)\n")
   cat("\n")
   cat("Out-of-sample domains: ", x$framework$N_dom_unobs, "\n")
-  if (x$model$correlation == "temporal" | x$model$correlation == "spatio-temporal") {
+  if (x$model$correlation == "temporal" |
+    x$model$correlation == "spatio-temporal") {
     cat("In-sample domains: ", x$framework$N_dom_smp / x$model$n_time, "\n")
     cat("Number of time periods: ", x$model$n_time, "\n")
     cat("\n")
@@ -92,7 +89,7 @@ print.fh <- function(x, ...) {
   cat("Variance and MSE estimation:\n")
   if (x$method$method == "reblup" | x$method$method == "reblupbc") {
     cat("Variance estimation method: robustified ml,", x$method$method, "\n")
-    
+
     if (x$method$method == "reblup") {
       cat("k = ", x$model$k, "\n")
     } else if (x$method$method == "reblupbc") {
@@ -101,13 +98,16 @@ print.fh <- function(x, ...) {
   } else {
     cat("Variance estimation method: ", x$method$method, "\n")
   }
-  
+
   if (x$model$correlation == "no") {
     cat("Variance of random effects: ", x$model$variance, "\n")
   } else {
-    cat("Estimated variance component(s): ", x$model$correlation, "correlation assumed\n")
-    cat("Variance of random effects: ", x$model$variance$variance,"\n")
-    cat("Spatial correlation parameter: ", x$model$variance$correlation,"\n")
+    cat(
+      "Estimated variance component(s): ", x$model$correlation,
+      "correlation assumed\n"
+    )
+    cat("Variance of random effects: ", x$model$variance$variance, "\n")
+    cat("Spatial correlation parameter: ", x$model$variance$correlation, "\n")
   }
   cat("MSE method: ", x$method$MSE_method, "\n")
   cat("\n")
@@ -119,9 +119,11 @@ print.fh <- function(x, ...) {
     } else {
       backtransformation <- x$transformation$backtransformation
     }
-    transform_data <- data.frame(Transformation  = x$transformation$transformation,
-                                 Back_transformation = backtransformation,
-                                 row.names       = ""
+    transform_data <- data.frame(
+      Transformation =
+        x$transformation$transformation,
+      Back_transformation = backtransformation,
+      row.names = ""
     )
   }
   if (is.null(transform_data)) {
@@ -130,4 +132,4 @@ print.fh <- function(x, ...) {
     cat("Transformation:\n")
     print(transform_data)
   }
-}
\ No newline at end of file
+}
